@@ -9,8 +9,6 @@ import math
 import numexpr
 import xarray
 import bottleneck
-import matplotlib
-import tabulate
 import numpy as np
 import xlsxwriter
 import xlrd
@@ -923,7 +921,6 @@ def parseTables(conf):
         fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
         fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x,'coerce'))
         fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
-        charges['Num'] = charges['Num'].map(lambda x: pd.to_numeric(x,'coerce'))
 
         feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
         feesheet = feesheet.dropna() 
@@ -969,10 +966,10 @@ def parseTables(conf):
         if bool(archive_out) and len(arc_ext) > 2:
             timestamp = start_time
             ar = pd.DataFrame({
-                'Path': pd.Series(paths),
+                'Path': pd.Series(queue),
                 'AllPagesText': b['AllPagesText'],
                 'Timestamp': timestamp
-                },index=range(0,pd.Series(paths).shape[0]))
+                },index=range(0,pd.Series(queue).shape[0]))
             arch = pd.concat([arch, ar],ignore_index=True)
             arch.fillna('',inplace=True)
             arch.dropna(inplace=True)
